@@ -38,6 +38,7 @@
 #'@export
 #'@examples
 #'library(stpm)
+#'set.seed(123)
 #'#Reading the data:
 #'data <- simdata_cont(N=2)
 #'head(data)
@@ -191,6 +192,7 @@ spm_continuous <- function(dat,
   # Current results:
   #results <- list(a=NULL, f1=NULL, Q=NULL, f=NULL, b=NULL, mu0=NULL, theta=NULL)
   results_tmp <- list(a=NULL, f1=NULL, Q=NULL, f=NULL, b=NULL, mu0=NULL, theta=NULL)
+  e <- new.env()
   iteration <- 0
   
   bounds <- list()
@@ -280,7 +282,7 @@ spm_continuous <- function(dat,
       dims <- dim(dat)
       res <- .Call("complikMD", dat, dims[1], dims[2], a, f1, Q, b, f, mu0, theta, k, pinv.tol, gomp, logmu0)
       
-      assign("results", results_tmp, envir=baseenv())
+      assign("results", results_tmp, envir=e)
       
       iteration <<- iteration + 1
       L.prev <<- res
@@ -321,7 +323,8 @@ spm_continuous <- function(dat,
   		 opts = opts,
        lb = bounds$lower_bound, ub = bounds$upper_bound)
   
-  final_results <- get("results",envir=baseenv())
+  final_results <- get("results",envir=e)
+  #final_results <- results_tmp
   final_results[["status"]] <- ans$status
   final_results[["LogLik"]] <- L.prev
   final_results[["objective"]] <- ans$objective
